$(document).ready(function() {
    var link = $('#change_form').attr('action');
    $('#id_page').change(function(){
        $('#msg_ok').hide();
        $.post(link, {
            'id_page': $(this).val(), 
            'action': 'getpage'
        }, function(data) {
            var obj = jQuery.parseJSON(data);
            jQuery.each(obj, function(k, v) {
                $('#' + v.name).val(v.value);
            });
        });
    });
    $('#btn_save').click(function(){
        $.post(link, $('#change_form').serialize(), function(data) {
            $('#msg_ok').hide();
            if (data == 1) {
                $('#msg_ok').show('slow');
            }
        });
        return false;
    });
    $('#btn_cancel').click(function(){
        $('#change_form')[0].reset();
        return false;
    });
})