<?php 
$lang['title'] = 'SEO-module';

$lang['not_found'] = 'Page is under construction.';

$lang['ln_page'] = 'Site pages';
$lang['ln_seo_title'] = 'SEO TITLE (up to 60 characters)';
$lang['ln_seo_keywords'] = 'SEO KEYWORDS (comma)';
$lang['ln_seo_description'] = 'SEO DESCRIPTION (up to 160 characters)';
$lang['btn_save'] = 'Save';
$lang['btn_cancel'] = 'Cancel';

$lang['msg_ok'] = 'Saved';