<?php 
$lang['title'] = 'SEO-модуль';

$lang['not_found'] = 'Сторінки ще не створені';

$lang['ln_page'] = 'Розділ сайту';
$lang['ln_seo_title'] = 'SEO TITLE(ДО 60 ЗНАКІВ)';
$lang['ln_seo_keywords'] = 'SEO KEYWORDS(через кому)';
$lang['ln_seo_description'] = 'SEO DESCRIPTION(ДО 160 ЗНАКІВ)';
$lang['btn_save'] = 'Зберегти';
$lang['btn_cancel'] = 'Відміна';

$lang['msg_ok'] = 'Дані збережені';
