.seo-content select,
.seo-content input[type="text"],
.seo-content textarea{
    border-radius: 0;
    width: 100%;
}
.seo-content textarea{
    max-width: 663px;
    min-width: 663px;
    width: 663px !important;
}
.seo-content input[type="text"]{
    padding: 6px 6px;
    margin-bottom: 7px;
    width: 663px;
}
.seo-content select{
    height: 35px;
    line-height: 35px;
    margin-top: 5px;
    margin-bottom: 0;
}
.seo-content{
    width: 944px;
    margin-top: 20px;
}
.seo-content td:first-of-type{
    width: 240px;
}
.seo-content h5{
    text-transform: uppercase;
    text-align: left;
}
.seo-content td{
    text-align: right;
    padding-right: 16px;
    vertical-align: top;
    line-height: 38px;
}
.seo-content .indent {
    padding-top: 20px;
}
.seo-content tr:last-of-type td:last-of-type{
    text-align: left;
}
.seo-content button{
    margin-top: 68px;
    padding: 4px 20px;
    margin-right: 24px;
}