<?php

return[
    'project_modules' => [
        'pages' => [
            'seo' => [
                'label'        => 'Управление SEO',
                'file'         => __DIR__ . '/../docs/seo.md',
                'position'     => 50,
                'acl_resource' => 'seo',
                'acl_action'   => 'edit_seo_manage',
                'uri'          => 'seo/manage',
            ],
        ]
    ]
];
