<?php 
$lang['title'] = 'SEO-модуль';

$lang['not_found'] = 'Страницы еще не созданы.';

$lang['ln_page'] = 'Раздел сайта';
$lang['ln_seo_title'] = 'SEO TITLE(ДО 60 ЗНАКОВ)';
$lang['ln_seo_keywords'] = 'SEO KEYWORDS(через запятую)';
$lang['ln_seo_description'] = 'SEO DESCRIPTION(ДО 160 ЗНАКОВ)';
$lang['btn_save'] = 'Сохранить';
$lang['btn_cancel'] = 'Отмена';

$lang['msg_ok'] = 'Данные сохранени';