<?php

if (!defined('BASEPATH'))
    exit('No direct script access allowed');

/**
 * Description of install
 *
 * @author Igor Ratsun
 */
class seo_install extends MX_Controller {

    public function __construct() {
        $this->lang->load('seo/install');
    }

    public function install() {
        $this->load->library('ciext/installer');
        $this->installer->install('seo', $this->lang->line('module_title'), array(
            'edit_seo_manage' => $this->lang->line('module_action')
                ), array(
            array('manage', $this->lang->line('module_title'), '', 'edit_seo_manage')
        ));

        return array('content' => $this->lang->line('module_installed'), 'title' => $this->lang->line('module_title'));
    }

    public function uninstall() {
        $this->load->library('ciext/installer');
        $this->installer->uninstall('seo');

        return array('content' => $this->lang->line('module_removed'), 'title' => $this->lang->line('module_title'));
    }

}

