{form_open}
<div class="alert alert-success" style="display:none" id="msg_ok">{msg_ok}</div>
<table class="seo-content">
    <tbody>
        <tr>
            <td><h5>{ln_page}</h5></td>
            <td>
                <select name="id_page" id="id_page">
                    {pages}
                    <option value="{id_resource_type_page}">{name}</option>
                    {/pages}
                </select>
            </td>
        </tr>
        <tr>
            <td colspan="2" class="indent"><h5>{ln_seo_title}</h5></td>
        </tr>
        {seo_title}
        <tr>
            <td>{lang}:</td>
            <td>
                <input type="text"  name="{name}" id="{name}" placeholder="" value="{value}">
            </td>
        </tr>
        {/seo_title}
        <tr>
            <td colspan="2" class="indent"><h5>{ln_seo_description}</h5></td>
        </tr>
        {seo_description}
        <tr>
            <td>{lang}:</td>
            <td>
                <textarea name="{name}" id="{name}" rows="3">{value}</textarea>
            </td>
        </tr>
        {/seo_description}
        <tr>
            <td colspan="2" class="indent"><h5>{ln_seo_keywords}</h5></td>
        </tr>
        {seo_keywords}
        <tr>
            <td>{lang}:</td>
            <td>
                <textarea  name="{name}" id="{name}" rows="3">{value}</textarea>
            </td>
        </tr>
        {/seo_keywords}
        <tr>
            <td></td>
            <td>
                <button type="submit" id="btn_save" class="btn btn-primary">{btn_save}</button>
                <button type="submit" class="btn" id="btn_cancel">{btn_cancel}</button>
            </td>
        </tr>
    </tbody>
</table>
{form_close}
